@@ -1,16 +1,17 @@
 package Finance::Robinhood;
-use 5.010;
+use 5.012;
 use strict;
 use warnings;
 use Carp;
-our $VERSION = "0.01";
-#use Data::Dump qw[ddx];
+our $VERSION = "0.02";
 use Moo;
 use HTTP::Tiny '0.056';
 use JSON::Tiny qw[decode_json];
 use strictures 2;
 use namespace::clean;
 use DateTime;
+our $DEBUG = !1;
+require Data::Dump if $DEBUG;
 #
 use lib '../../lib';
 use Finance::Robinhood::Account;
@@ -62,15 +63,18 @@ my %endpoints = (
                 'cards'                 => 'midlands/notifications/stack/',
                 'cards/dismiss' => 'midlands/notifications/stack/%s/dismiss/',
                 'orders'        => 'orders/',
-                'password_reset'          => 'password_reset/request/',
+                'password_reset'          => 'password_reset/',
+                'password_reset/request'  => 'password_reset/request/',
                 'quote'                   => 'quote/',
                 'quotes'                  => 'quotes/',
                 'quotes/historicals'      => 'quotes/historicals/',
                 'user'                    => 'user/',
+                'user/id'                 => 'user/id/',
                 'user/additional_info'    => 'user/additional_info/',
                 'user/basic_info'         => 'user/basic_info/',
                 'user/employment'         => 'user/employment/',
                 'user/investment_profile' => 'user/investment_profile/',
+                'user/identity_mismatch'  => 'user/identity_mismatch',
                 'watchlists'              => 'watchlists/',
                 'watchlists/bulk_add'     => 'watchlists/%s/bulk_add/'
 );
@@ -85,15 +89,12 @@ sub endpoint {
 #
 my ($client, $res);
 my %headers = (
-    'Accept' => '*/*',
-
-    #'Accept-Encoding' => 'gzip, deflate',
-    'Accept-Language' =>
-        'en;q=1, fr;q=0.9, de;q=0.8, ja;q=0.7, nl;q=0.6, it;q=0.5',
-    'Content-Type' => 'application/x-www-form-urlencoded; charset=utf-8',
-    'X-Robinhood-API-Version' => '1.0.0',
-    'Connection'              => 'keep-alive',
-    'User-Agent' => 'Robinhood/823 (iPhone; iOS 7.1.2; Scale/2.00)'
+         'Accept' => '*/*',
+         'Accept-Language' =>
+             'en;q=1, fr;q=0.9, de;q=0.8, ja;q=0.7, nl;q=0.6, it;q=0.5',
+         'Content-Type' => 'application/x-www-form-urlencoded; charset=utf-8',
+         'X-Robinhood-API-Version' => '1.70.0',
+         'User-Agent' => 'Robinhood/823 (iPhone; iOS 7.1.2; Scale/2.00)'
 );
 sub errors { shift; carp shift; }
 
@@ -101,32 +102,142 @@ sub login {
     my ($self, $username, $password) = @_;
 
     # Make API Call
-    my $rt = _send_request(undef, 'POST',
-                           Finance::Robinhood::endpoint('login'),
-                           {username => $username,
-                            password => $password
-                           }
-    );
+    my ($status, $data, $raw)
+        = _send_request(undef, 'POST',
+                        Finance::Robinhood::endpoint('login'),
+                        {username => $username,
+                         password => $password
+                        }
+        );
 
     # Make sure we have a token.
-    if (!$rt || !defined($rt->{token})) {
-        $self->errors('auth(): Robinhood API did not return a valid token.');
+    if ($status != 200 || !defined($data->{token})) {
+        $self->errors(join ' ', @{$data->{non_field_errors}});
         return !1;
     }
 
     # Set the token we just received.
-    return $self->_set_token($rt->{token});
+    return $self->_set_token($data->{token});
 }
 
 sub logout {
-    my ($self, $username, $password) = @_;
+    my ($self) = @_;
 
     # Make API Call
-    my $rt = _send_request(undef, 'POST',
-                           Finance::Robinhood::endpoint('logout'));
+    my ($status, $rt, $raw)
+        = $self->_send_request('POST',
+                               Finance::Robinhood::endpoint('logout'));
+    return $status == 200 ?
 
-    # The old token is now invalid, so we might as well delete it
-    return $self->_set_token(());
+        # The old token is now invalid, so we might as well delete it
+        $self->_set_token(())
+        : ();
+}
+
+sub forgot_password {
+    my $self = shift if ref $_[0] && ref $_[0] eq __PACKAGE__;
+    my ($email) = @_;
+
+    # Make API Call
+    my ($status, $rt, $raw)
+        = _send_request(undef, 'POST',
+                       Finance::Robinhood::endpoint('password_reset/request'),
+                       {email => $email});
+    return $status == 200;
+}
+
+sub change_password {
+    my $self = shift if ref $_[0] && ref $_[0] eq __PACKAGE__;
+    my ($user, $password, $token) = @_;
+
+    # Make API Call
+    my ($status, $rt, $raw)
+        = _send_request(undef, 'POST',
+                        Finance::Robinhood::endpoint('password_reset'),
+                        {username => $user,
+                         password => $password,
+                         token    => $token
+                        }
+        );
+    return $status == 200;
+}
+
+sub user_info {
+    my ($self) = @_;
+    my ($status, $data, $raw)
+        = $self->_send_request('GET', Finance::Robinhood::endpoint('user'));
+    return $status == 200 ?
+        map { $_ => $data->{$_} } qw[email id last_name first_name username]
+        : ();
+}
+
+sub user_id {
+    my ($self) = @_;
+    my ($status, $data, $raw)
+        = $self->_send_request('GET',
+                               Finance::Robinhood::endpoint('user/id'));
+    return $status == 200 ? $data->{id} : ();
+}
+
+sub basic_info {
+    my ($self) = @_;
+    my ($status, $data, $raw)
+        = $self->_send_request('GET',
+                             Finance::Robinhood::endpoint('user/basic_info'));
+    return $status != 200 ?
+        ()
+        : ((map { $_ => _2_datetime(delete $data->{$_}) }
+                qw[date_of_birth updated_at]
+           ),
+           map { m[url] ? () : ($_ => $data->{$_}) } keys %$data
+        );
+}
+
+sub additional_info {
+    my ($self) = @_;
+    my ($status, $data, $raw)
+        = $self->_send_request('GET',
+                               Finance::Robinhood::endpoint(
+                                                       'user/additional_info')
+        );
+    return $status != 200 ?
+        ()
+        : ((map { $_ => _2_datetime(delete $data->{$_}) } qw[updated_at]),
+           map { m[user] ? () : ($_ => $data->{$_}) } keys %$data);
+}
+
+sub employment_info {
+    my ($self) = @_;
+    my ($status, $data, $raw)
+        = $self->_send_request('GET',
+                             Finance::Robinhood::endpoint('user/employment'));
+    return $status != 200 ?
+        ()
+        : ((map { $_ => _2_datetime(delete $data->{$_}) } qw[updated_at]),
+           map { m[user] ? () : ($_ => $data->{$_}) } keys %$data);
+}
+
+sub investment_profile {
+    my ($self) = @_;
+    my ($status, $data, $raw)
+        = $self->_send_request('GET',
+                               Finance::Robinhood::endpoint(
+                                                    'user/investment_profile')
+        );
+    return $status != 200 ?
+        ()
+        : ((map { $_ => _2_datetime(delete $data->{$_}) } qw[updated_at]),
+           map { m[user] ? () : ($_ => $data->{$_}) } keys %$data);
+}
+
+sub identity_mismatch {
+    my ($self) = @_;
+    my ($status, $data, $raw)
+        = $self->_send_request('GET',
+                               Finance::Robinhood::endpoint(
+                                                     'user/identity_mismatch')
+        );
+    return $status == 200 ? $self->_paginate($data) : ();
 }
 
 sub accounts {
@@ -252,76 +363,7 @@ sub quote_price {
     return shift->quote(shift)->[0]{last_trade_price};
 }
 
-sub _place_order {
-    my ($self, $instrument, $quantity, $side, $order_type, $bid_price,
-        $time_in_force, $stop_price)
-        = @_;
-    $time_in_force //= 'gfd';    # Good For Day
-
-#warn Finance::Robinhood::endpoint('orders');
-#warn Finance::Robinhood::endpoint('accounts') . $self->account()->account_number() . '/';
-# Make API Call
-    #ddx $instrument;
-    my $rt = $self->_send_request(
-        'GET',
-        Finance::Robinhood::endpoint('orders'),
-        {account => Finance::Robinhood::endpoint('accounts')
-             . $self->account()->account_number() . '/',
-         instrument    => $instrument->url(),
-         quantity      => $quantity,
-         side          => $side,
-         symbol        => $instrument->symbol(),
-         time_in_force => $time_in_force,
-         trigger       => 'immediate',
-         type          => $order_type,
-         ($order_type eq 'market' ?
-              (    #price => $instrument->bid_price()
-              )
-          : $order_type eq 'limit'     ? (price      => $bid_price)
-          : $order_type eq 'stop_loss' ? (stop_price => $stop_price)
-          : $order_type eq 'stop_limit'
-          ? (price => $bid_price, stop_price => $stop_price)
-          :
-
-            # TODO: stop_limit and stop_loss order types are works in progress
-              ()
-         )
-        }
-    );
-    #ddx $rt;
-    return $rt ? Finance::Robinhood::Order->new($rt) : ();
-}
-
-sub place_buy_order {    # TODO: Test and document
-    my ($self, $instrument, $quantity, $order_type, $bid_price) = @_;
-
-# TODO: Make this accept a hash with keys:
-# { bid_price  => $int,
-#   quantity   => $int,
-#   instrument => Finance::Robinhood::Instrument,
-#   # Optional w/ defaults
-#   trigger    => 'gfd' (Good For Day, other options are 'gtc' Good Till Cancelled, 'oco' Order Cancels Other)
-#   time       => 'immediate' (execute trade now or cancel, other option is 'day' where the trade is canceled if not executed by day's end)
-#   type       => 'market'
-# }
-#    def place_sell_order(self, symbol, quantity, order_type=None, bid_price=None):
-#
-    return
-        $self->_place_order($instrument, $quantity, 'buy',
-                            $order_type, $bid_price);
-}
-
-sub place_sell_order {    # TODO: Test and document
-    my ($self, $instrument, $quantity, $order_type, $bid_price) = @_;
-
-#    def place_sell_order(self, symbol, quantity, order_type=None, bid_price=None):
-#
-    return
-        $self->_place_order($instrument, $quantity, 'sell',
-                            $order_type, $bid_price);
-}
-
-sub order {
+sub locate_order {
     my ($self, $order_id) = @_;
     my $result = $self->_send_request('GET',
                     Finance::Robinhood::endpoint('orders') . $order_id . '/');
@@ -344,62 +386,9 @@ sub list_orders {
     );
     $result // return !1;
     return () if !$result;
-    $result->{previous} =~ m[\?cursor=(.+)$] if defined $result->{previous};
-    my $prev = $1 // ();
-    $result->{next} =~ m[\?cursor=(.+)$] if defined $result->{next};
-    my $next = $1 // ();
-    return {
-          results => [
-              map { Finance::Robinhood::Order->new($_) } @{$result->{results}}
-          ],
-          previous => $prev,
-          next     => $next
-    };
+    return $self->_paginate($result, 'Finance::Robinhood::Order');
 }
 
-sub cancel_order {
-    my ($self, $order) = @_;
-    return $self->_send_request('GET', $order->_get_cancel(), {});
-}
-
-# TODO:
-#Pulls user info from API and stores it in Robinhood object
-
-#sub get_user_info {
-#    my $self = shift;
-#    my $response
-#        = $self->_send_request('GET', Finance::Robinhood::endpoint('user'));
-    #ddx $response;
-    #ddx $self->_send_request('GET', $response->{additional_info});
-    #ddx $self->_send_request('GET', $response->{basic_info});
-    #ddx $self->_send_request('GET', $response->{employment});
-    #ddx $self->_send_request('GET', $response->{id_info});
-    #ddx $self->_send_request('GET', $response->{international_info});
-    #ddx $self->_send_request('GET', $response->{investment_profile});
-
-    #res = self.session.get(self.endpoints['user'])
-    #if res.status_code == 200:
-    #    self.first_name = res.json()['first_name']
-    #    self.last_name = res.json()['last_name']
-    #else:
-    #    raise Exception("Could not get user info: " + res.text)
-    #res = self.session.get(self.endpoints['user/basic_info'])
-    #if res.status_code == 200:
-    #    res = res.json()
-    #    self.phone_number = res['phone_number']
-    #    self.city = res['city']
-    #    self.number_dependents = res['number_dependents']
-    #    self.citizenship = res['citizenship']
-    #    self.marital_status = res['marital_status']
-    #    self.zipcode = res['zipcode']
-    #    self.state_residence = res['state']
-    #    self.date_of_birth = res['date_of_birth']
-    #    self.address = res['address']
-    #    self.tax_id_ssn = res['tax_id_ssn']
-    #else:
-    #    raise Exception("Could not get basic user info: " + res.text)
-#}
-
 # Methods under construction
 sub cards {
     return shift->_send_request('GET', Finance::Robinhood::endpoint('cards'));
@@ -439,12 +428,12 @@ sub create_watchlist {
 
 sub delete_watchlist {
     my ($self, $watchlist) = @_;
-    my ($result, $response)
+    my ($status, $result, $response)
         = $self->_send_request('DELETE',
                                Finance::Robinhood::endpoint('watchlists')
                                    . $watchlist->name() . '/'
         );
-    return $result->{status} == 204 ? 1 : !1;
+    return $status == 204;
 }
 
 sub watchlists {
@@ -466,23 +455,30 @@ sub watchlists {
     return $self->_paginate($result, 'Finance::Robinhood::Watchlist');
 }
 
+# ---------------- Private Helper Functions --------------- //
+# Send request to API.
+#
 sub _paginate {    # Paginates results
     my ($self, $res, $class) = @_;
     $res->{previous} =~ m[\?cursor=(.+)$] if defined $res->{previous};
     my $prev = $1 // ();
     $res->{next} =~ m[\?cursor=(.+)$] if defined $res->{next};
     my $next = $1 // ();
-    return {results => [map { $class->new(%$_, ($self ? (rh => $self) : ())) }
-                            @{$res->{results}}
-            ],
-            previous => $prev,
-            next     => $next
+    return {
+        results => (
+            defined $class ?
+                [
+                map {
+                    $class->new(%$_, ($self ? (rh => $self) : ()))
+                } @{$res->{results}}
+                ]
+            : $res->{results}
+        ),
+        previous => $prev,
+        next     => $next
     };
 }
 
-# ---------------- Private Helper Functions --------------- //
-# Send request to API.
-#
 sub _send_request {
 
     # TODO: Expose errors (400:{detail=>'Not enough shares to sell'}, etc.)
@@ -499,19 +495,24 @@ sub _send_request {
     $client = HTTP::Tiny->new() if !defined $client;
 
     # Make API call.
-    #warn $url;
-    #ddx($verb, $url,
-    #    {headers => {%headers,
-    #                 ($self && defined $self->token()
-    #                  ? (Authorization => 'Token ' . $self->token())
-    #                  : ()
-    #                 )
-    #     },
-    #     (defined $data ? (content => $client->www_form_urlencode($data))
-    #      : ()
-    #     )
-    #    }
-    #);
+    if ($DEBUG) {
+        warn "$verb $url";
+        require Data::Dump;
+        Data::Dump::ddx($verb, $url,
+                        {headers => {%headers,
+                                     ($self && defined $self->token()
+                                      ? (Authorization => 'Token '
+                                          . $self->token())
+                                      : ()
+                                     )
+                         },
+                         (defined $data
+                          ? (content => $client->www_form_urlencode($data))
+                          : ()
+                         )
+                        }
+        );
+    }
 
     #warn $post;
     $res = $client->request($verb, $url,
@@ -531,14 +532,17 @@ sub _send_request {
     );
 
     # Make sure the API returned happy
-    #ddx $res;
-    if ($res->{status} != 200 && $res->{status} != 201) {
-        carp 'Robinhood did not return a status code of 200 or 201. ('
-            . $res->{status} . ')';
-        #ddx $res;
-        return wantarray ? ((), $res) : ();
+    if ($DEBUG) {
+        require Data::Dump;
+        Data::Dump::ddx($res);
     }
 
+    #if ($res->{status} != 200 && $res->{status} != 201) {
+    #    carp 'Robinhood did not return a status code of 200 or 201. ('
+    #        . $res->{status} . ')';
+    #    #ddx $res;
+    #    return wantarray ? ((), $res) : ();
+    #}
     # Decode the response.
     my $json = $res->{content};
 
@@ -547,23 +551,14 @@ sub _send_request {
     my $rt = $json ? decode_json($json) : ();
 
     # Return happy.
-    return wantarray ? ($rt, $res) : $rt;
+    return wantarray ? ($res->{status}, $rt, $res) : $rt;
 }
 
-# Coerce strings into DateTime objects
+# Coerce ISO 8601-ish strings into DateTime objects
 sub _2_datetime {
+    return if !$_[0];
     $_[0]
         =~ m[(\d{4})-(\d\d)-(\d\d)(?:T(\d\d):(\d\d):(\d\d)(?:\.(\d+))?(.+))?];
-
-    # "2016-03-11T17:59:48.026546Z",
-    #warn 'Y:' . $1;
-    #warn 'M:' . $2;
-    #warn 'D:' . $3;
-    #warn 'h:' . $4;
-    #warn 'm:' . $5;
-    #warn 's:' . $6;
-    #warn 'n:' . $7;
-    #warn 'z:' . $8;
     DateTime->new(year  => $1,
                   month => $2,
                   day   => $3,
@@ -630,10 +625,68 @@ use in future calls to C<new( ... )>.
 =head2 C<logout( )>
 
     my $token = $rh->login($user, $password);
+    # ...do some stuff... buy... sell... idk... stuff... and then...
     $rh->logout( ); # Goodbye!
 
-Logs you out of Robinhood by invalidating the token returned by
-C<login( ... )> and passed to C<new(...)>.
+Logs you out of Robinhood by forcing the token returned by
+C<login( ... )> or passed to C<new(...)> to expire.
+
+I<Note>: This will log you out I<everywhere> because Robinhood generates a
+single authorization token per account at a time!
+
+=head2 C<forgot_password( ... )>
+
+    Finance::Robinhood::forgot_password('contact@example.com');
+
+This requests a password reset email to be sent from Robinhood.
+
+=head2 C<change_password( ... )>
+
+    Finance::Robinhood::change_password( $username, $password, $token );
+
+Robinhood sends a link to the registered email address when the
+C<password_reset( ... )> function is called. In the email there is a link with
+the username and a token. You must provide a new password.
+
+=head2 C<user_info( )>
+
+    my %info = $rh->user_info( );
+    say 'My name is ' . $info{first_name} . ' ' . $info{last_name};
+
+Returns very basic information (name, email address, etc.) about the currently
+logged in account as a hash.
+
+=head2 C<user_id( )>
+
+    my $user_id = $rh->user_id( );
+
+Returns the ID Robinhood uses to identify this particular account. You could
+also gather this information with the C<user_info( )> method.
+
+=head2 C<basic_info( )>
+
+This method grabs more private information about the user including their date
+of birth, marital status, and the last four digits of their social security
+number.
+
+=head2 C<additional_info( )>
+
+This method grabs information about the user that the SEC would like to know
+including any affilations with publically traded securities.
+
+=head2 C<employment_info( )>
+
+This method grabs information about the user's current employment status and
+(if applicable) current job.
+
+=head2 C<investment_profile( )>
+
+This method grabs answers about the user's investment experience gathered by
+the survey performed during registration.
+
+=head2 C<identity_mismatch( )>
+
+Returns a paginated list of identification information.
 
 =head2 C<accounts( ... )>
 
@@ -677,28 +730,12 @@ them, use the C<next> or C<previous> values.
 Returns a sample list of top securities as Finance::Robinhood::Instrument
 objects along with C<next> and C<previous> cursor values.
 
-=head2 C<place_buy_order( ... )>
+=head2 C<locate_order( ... )>
 
-    $rh->place_buy_order($instrument, $number, $type);
+    my $order = $rh->locate_order( $order_id );
 
-Puts in an order to buy a given C<$number> of shares of the given
-C<$instrument>. Currently, only C<'market'> type sales have been tested. A
-Finance::Robinhood::Order object is returned if the order was sucessful.
-
-=head2 C<place_sell_order( ... )>
-
-    $rh->place_sell_order($instrument, $number, $type);
-
-Puts in an order to sell a given C<$number> of shares of the given
-C<$instrument>. Currently, only C<'market'> type sales have been tested. A
-Finance::Robinhood::Order object is returned if the order was sucessful.
-
-=head2 C<cancel_order( ... )>
-
-    my $order = $rh->place_sell_order($instrument, $number, $type);
-    $rh->cancel_order( $order ); # Whoops! Nevermind!
-
-Cancels a buy or sell order if called before the order is executed.
+Returns a blessed Finance::Robinhood::Order object related to the about the
+buy or sell order with the given id.
 
 =head2 C<list_orders( ... )>
 
@@ -714,13 +751,6 @@ You'll likely generate more than a hand full of buy and sell orders which
 would generate more than a single page of results. To gather them, use the
 C<next> or C<previous> values.
 
-=head2 C<order( ... )>
-
-    my $order = $rh->order( $order_id );
-
-Returns a Finance::Robinhood::Order object which contains information about an
-order and its status.
-
 =head2 C<quote( ... )>
 
     my %msft = $rh->quote('MSFT');
