@@ -3,7 +3,7 @@ use 5.010;
 use strict;
 use warnings;
 use Carp;
-our $VERSION = "0.01";
+our $VERSION = "0.02";
 use Moo;
 use JSON::Tiny qw[decode_json];
 use strictures 2;
@@ -15,14 +15,18 @@ has $_ => (is => 'ro', required => 1, writer => "_set_$_")
      cash_held_for_orders deactivated deposit_halted margin_balances
      max_ach_early_access_amount only_position_closing_trades sma
      sma_held_for_orders sweep_enabled type uncleared_deposits unsettled_funds
-     updated_at withdrawal_halted]
+     withdrawal_halted url]
     );
+has $_ => (is       => 'ro',
+           required => 1,
+           coerce   => \&Finance::Robinhood::_2_datetime
+) for (qw[updated_at]);
 has $_ => (is => 'bare', required => 1, accessor => "_get_$_", weak_ref => 1)
     for (qw[rh]);
 
 sub positions {
     my ($self, $type) = @_;
-    my $result = $self->_get_rh()->_send_request(
+    my ($status, $result, $raw) = $self->_get_rh()->_send_request(
         'GET',
         sprintf(Finance::Robinhood::endpoint('accounts/positions'),
                 $self->account_number()
@@ -44,7 +48,7 @@ sub positions {
 
 sub portfolio {
     my ($self) = @_;
-    my ($result)
+    my ($status, $result, $raw)
         = $self->_get_rh()->_send_request('GET',
                            Finance::Robinhood::endpoint('accounts/portfolios')
                                . $self->account_number()
