@@ -1,7 +1,7 @@
 package Finance::Robinhood::Order;
 use 5.010;
 use Carp;
-our $VERSION = "0.02_001";
+our $VERSION = "0.02";
 use Moo;
 use strictures 2;
 use namespace::clean;
@@ -106,7 +106,7 @@ sub cancel {
 
 =head1 NAME
 
-Finance::Robinhood::Order - Order to Buy or Sell a Security
+Finance::Robinhood::Order - Order to buy or sell a security
 
 =head1 SYNOPSIS
 
@@ -120,7 +120,7 @@ Finance::Robinhood::Order - Order to Buy or Sell a Security
         instrument    => $bill,
         side          => 'buy',
         type          => 'market',
-        trigger       => 'on_close',
+        trigger       => 'immediate',
         time_in_force => 'gfd',
         quantity      => 300
     );
@@ -140,18 +140,16 @@ This class has several getters and a few methods as follows...
 
 =head2 C<new( ... )>
 
-The main event! Odds are, this is what you installed Finance::Robinhood to do:
-buy and sell securities without commisions.
+The main event!
+
+Odds are, this is what you installed Finance::Robinhood to do: buy ad sell.
 
 Please note that if the call to C<new( ... )> fails for any reason (not enough
 buying power, etc.) this will C<confess( ... )> so it's probably a good idea
-to wrap it in an eval or something.
+to wrap this in an eval or something.
 
 There are some keys that are required for all orders and then there are some
-that only apply for certain types of orders. Different C<type> and C<trigger>
-combinations can make trading a lot less risky so please check out the
-L<order cheat sheet|/"Order Cheat Sheet"> below for easy stop loss and stop
-limit orders.
+that only apply for certain types of orders like stop loss and stop limit.
 
 These are the required keys for all orders:
 
@@ -159,20 +157,20 @@ These are the required keys for all orders:
 
 =item C<account>
 
-A Finance::Robinhood::Account object. You can get a list of these with the
-C<accounts( )> method found in Finance::Robinhood.
+A Finance::Robinhood::Account.
 
 =item C<instrument>
 
-A Finance::Robinhood::Instrument. The easiest way to get these is to use the
-C<instrument( )> method found in Finance::Robinhood.
+A Finance::Robinhood::Instrument
 
 =item C<type>
 
-This is a string which may be one of the following:
+String which may be one of the following:
 
 =over
 
+=item C<stop>
+
 =item C<market>
 
 =item C<limit>
@@ -187,22 +185,10 @@ Which may be one of the following:
 
 =item C<immediate>
 
-The order is executed immediatly.
-
 =item C<stop>
 
-The order depends on a defined C<stop_price> and then automatically converts
-into whatever C<type> you provided.
-
 =item C<on_close>
 
-The order executes as close to the end of the day as possible.
-
-Please note that there are certain timing rules placed on Market On Close
-(MOC) and Limit On Close (LOC) orders. All (MOC) orders must be submitted by
-3:45pm on the NYSE and by 3:50pm EST on the Nasdaq. Neither exchange allows
-for the modification or cancellation of MOC orders after those times.
-
 =back
 
 =item C<time_in_force>
@@ -213,31 +199,23 @@ Which may be one of the following:
 
 =item C<gfd>
 
-Good For Day - The order is automatically cancelled at the end of the trading
-day. This can lead to partial executions.
+Good For Day
 
 =item C<gtc>
 
-Good 'Till Cancelled - The order will never cancel automatically. You must do
-so manually.
+Good 'Till Cancelled
 
 =item C<fok>
 
-Fill or Kill - When triggered, the entire order must execute in full
-immediatly or the entire order is cancelled.
-
-Note that FOK orders are no longer used on the NYSE.
+Fill or Kill
 
 =item C<ioc>
 
-Immediate or Cancel - When triggered, the order must execute or the order is
-cancelled. IOC orders allow for partial executions unlike FOK.
+Immediate or Cancel
 
 =item C<opg>
 
-Opening - The order is executed at or as close to when the market opens.
-
-Note that OPG orders are not used on Nasdaq.
+Opening
 
 =back
 
@@ -260,23 +238,21 @@ sell.
 
 =back
 
-In addition to the above, there are some situational values you may need to
-pass. These include:
+=head3 Market Sell Order
 
-=over
+When placed, market sell orders get whatever the current asking price is when
+triggered.
 
-=item C<price>
 
-This is used in limit, stop limit, and stop loss orders where the order will
-only execute when the going rate hits the given price.
 
-=item C<stop_price>
+# NAME          TYPE      SIDE      REQUIREMENTS
+# market        market    buy       trigger=immediate, type=market
+# limit         limit     buy       trigger=immediate, type=limit
+# stop_limit    limit     buy       trigger=stop, stop_price=%d, type=market
+# stop_loss
+# stop_limit    limit     sell      price={minimum}, stop_price=%d, trigger=stop, type=limt
 
-This is used in stop limit and stop loss orders where the trigger is C<stop>
-and the order is automatically converted when the price hits the given
-C<stop_price>.
 
-=back
 
 =head2 C<account( )>
 
@@ -328,7 +304,7 @@ Total current value of the order.
 
 Total number of shares ordered or put up for sale.
 
-=head2 C<cumulative_quantity( )>
+=head2 C<cumulative_quantity>
 
 Total number of shares which have executed so far.
 
@@ -343,9 +319,16 @@ Indicates which side of the deal you were on: C<buy> or C<sell>.
 =head2 C<state( )>
 
 The current state of the order. For example, completly executed orders have a
-C<filled> state. The current state may be any of the following: C<queued>,
-C<unconfirmed>, C<confirmed>, C<partially_filled>, C<filled>, C<rejected>,
-C<cancelled>, C<failed>.
+C<filled> state. The current state may be any of the following:
+
+    queued
+    unconfirmed
+    confirmed
+    partially_filled
+    filled
+    rejected
+    cancelled
+    failed
 
 =head2 C<stop_price( )>
 
@@ -363,14 +346,23 @@ This may be one of the following:
 
 =head2 C<trigger( )>
 
-May be one of the following: C<immediate>, C<on_close>, C<stop>
+May be one of the following:
+
+    immediate
+    on_close
+    stop
 
 I<Note>: Support for C<opg> orders may indicate support for C<loo> and C<moo>
 triggers but I have yet to test it.
 
 =head2 C<type( )>
 
-May be one of the following: C<market> or C<limit>.
+May be one of the following:
+
+    market
+    limit
+    stop_limit
+    stop_loss
 
 =head2 C<created_at( )>
 
@@ -384,118 +376,6 @@ The timestamp of the most recent execution.
 
 Timestamp of the last change made to this order.
 
-=head1 Order Cheat Sheet
-
-This is a little cheat sheet for creating certain types of orders:
-
-=head2 Market Sell
-
-A market sell gets you whatever the current ask price is at the exact moment
-of execution.
-
-    my $order = Finance::Robinhood::Order->new(
-        type    => 'market',
-        trigger => 'immediate',
-        side    => 'sell',
-        ...
-    );
-
-=head2 Limit Sell
-
-Limit sells allow you specify the minimum amount you're willing to receive per
-share.
-
-    my $order = Finance::Robinhood::Order->new(
-        type    => 'limit',
-        trigger => 'immediate',
-        price   => 200.45,
-        side    => 'sell',
-        ...
-    );
-
-=head2 Stop Loss Sell
-
-When the bid price drops below the stop price, the order is converted to a
-market order.
-
-    my $order = Finance::Robinhood::Order->new(
-        type       => 'market',
-        trigger    => 'stop',
-        stop_price => 200.45,
-        side       => 'sell',
-        ...
-    );
-
-=head2 Stop Limit Sell
-
-When the bid price drops below the stop price, the order is converted to a
-limit order at the given price. In the following example, when the price
-reaches $200.45, the order is converted into a limit order at $199.5 a share.
-
-    my $order = Finance::Robinhood::Order->new(
-        type       => 'limit',
-        trigger    => 'stop',
-        stop_price => 200.45,
-        price      => 199.5
-        side       => 'sell',
-        ...
-    );
-
-=head2 Market Buy
-
-When triggered, this attempts to execute at the best current price. This may
-be above both the current bid and ask price.
-
-    my $order = Finance::Robinhood::Order->new(
-        type       => 'market',
-        trigger    => 'immediate',
-        side       => 'buy',
-        ...
-    );
-
-=head2 Limit Buy
-
-You may set the maximum amount you're willing to pay per share with a limit
-buy.
-
-    my $order = Finance::Robinhood::Order->new(
-        type       => 'limit',
-        trigger    => 'immediate',
-        price      => 2.65,
-        side       => 'buy',
-        ...
-    );
-
-=head2 Stop Loss Buy
-
-This order type allows you to set a price at which your order converts to a
-simple market order. In the following example, when the price rises above
-$2.30/share, the order is converted to a market order and executed at the best
-available price.
-
-    my $order = Finance::Robinhood::Order->new(
-        type       => 'market',
-        trigger    => 'stop',
-        stop_price => 2.30,
-        side       => 'buy',
-        ...
-    );
-
-=head2 Stop Limit Buy
-
-This order type allows you to set a price that converts your order to a limit
-order. In this example, when the price hits $6/share, the order turns into
-a limit buy with a C<stop_price> of $6.15/share.
-
-    my $order = Finance::Robinhood::Order->new(
-        type       => 'limit',
-        trigger    => 'stop',
-        price      => 6.15,
-        stop_price => 6,
-        side       => 'buy',
-        ...
-    );
-
 =head1 LEGAL
 
 This is a simple wrapper around the API used in the official apps. The author
